Improve this doc

# Error: ng:cpws
Copying Window or Scope

    Can't copy! Making copies of Window or Scope instances is not supported.

## Description

Copying Window or Scope instances is not supported because of cyclical and self references. Avoid copying windows and scopes, as well as any other cyclical or self-referential structures. Note that trying to deep copy an object containing cyclical references that is neither a window nor a scope will cause infinite recursion and a stack overflow.